@@ -95,10 +95,13 @@ def training_callback(base_cfg, data_config):
     cfg=Config()
     train(cfg)
 
-def make_training_app(function=training_callback,columns=[3, 3]):
+def make_training_app(function=training_callback,columns=[4, 4],window_size=(1600,800)):
     base_config=get_base_config()
     data_config=get_data_config()
-    app = make_app(function=function, args=(base_config, data_config), columns=columns)
+    app = make_app(function=function, args=(base_config, data_config), columns=columns,window_size=window_size)
     return app
 
 
+if __name__ == '__main__':
+    make_training_app().run()
+
